<?php
/*
Plugin Name: eADV VIP
Plugin URI: https://www.eadv.it
Description: Plugin riservato ai publishers VIP di eADV
Version: 1.0.4
Author: TAGMOOD S.R.L.
Author URI: https://www.tagmood.it
*/

/**
 * In questo modo, quando viene richiesta la pagina /ads.txt, viene effettuato un redirect verso l'URL specificato utilizzando l'ID del sito impostato tramite una pagina di configurazione.
 */
function eadv_handle_ads_txt($wp)
{
    $request = isset($_SERVER['REQUEST_URI']) ? esc_url_raw(wp_unslash($_SERVER['REQUEST_URI'])) : false;
    if ('/ads.txt' === $request) {
        $site_id = get_option('eadv_site_id');
        $url = 'https://panel.eadv.it/extads.txt?sid=' . $site_id;
        wp_redirect($url, 301);
        exit;
    }
}
add_action('init', 'eadv_handle_ads_txt', 1);

/**
 * Per inserire il codice javascript prima della chiusura del tag </body>, puoi utilizzare il hook di azione di WordPress wp_enqueue_scripts.
 */
function eadv_insert_javascript()
{
    $magic_code = get_option('eadv_magic_code_id');
    $script_src = 'https://track.eadv.it/' . $magic_code . '.php';
    wp_enqueue_script('eadv_tracking_script', $script_src, array(), '', true);
}
add_action('wp_enqueue_scripts', 'eadv_insert_javascript');

/**
 * Per inserire il <link> con preconnect nel tag <head></head> della pagina.
 */
function eadv_insert_preconnect() {
    echo '<link href="https://track.eadv.it" rel="preconnect">';
}
add_action('wp_head', 'eadv_insert_preconnect');

/**
 * Nel tuo file principale del plugin, crea una funzione per aggiungere una nuova voce di menu nell'area di amministrazione di WordPress.
 */
function eadv_add_options_page()
{
    add_options_page(
        'eADV VIP Plugin Options',
        'eADV VIP',
        'manage_options',
        'eadv-vip-plugin',
        'eadv_options_page'
    );
}
add_action('admin_menu', 'eadv_add_options_page');

/**
 * Crea una funzione per la visualizzazione della pagina di opzioni.
 */
function eadv_options_page()
{
    ?>
<div class="wrap">
	<h1>eADV VIP</h1>
	<form method="post" action="options.php">
		<?php
    settings_fields('eadv_options');
    do_settings_sections('eadv-vip-plugin');
    submit_button();
    ?>
	</form>
</div>
<?php
}

/**
 * Registra le opzioni del plugin utilizzando la funzione register_setting.
 */
function eadv_register_settings()
{
    register_setting(
        'eadv_options',
        'eadv_site_id',
        array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => ''
        )
    );
    register_setting(
        'eadv_options',
        'eadv_magic_code_id',
        array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => ''
        )
    );
}
add_action('admin_init', 'eadv_register_settings');

/**
 * Aggiungi una sezione per le opzioni del plugin utilizzando la funzione add_settings_section.
 */
function eadv_add_settings_section()
{
    add_settings_section(
        'eadv_section',
        'eADV VIP Plugin Settings',
        'eadv_section_callback',
        'eadv-vip-plugin'
    );
}
add_action('admin_init', 'eadv_add_settings_section');

function eadv_section_callback()
{
    echo '<p>Imposta il plugin eADV VIP.</p>';
}


/**
 * Aggiungi i campi di input per le opzioni del plugin utilizzando la funzione add_settings_field.
 */
function eadv_add_settings_fields()
{
    add_settings_field(
        'eadv_site_id',
        'ID del sito',
        'eadv_site_id_callback',
        'eadv-vip-plugin',
        'eadv_section'
    );
    add_settings_field(
        'eadv_magic_code_id',
        'Magic code ID',
        'eadv_magic_code_id_callback',
        'eadv-vip-plugin',
        'eadv_section'
    );
}
add_action('admin_init', 'eadv_add_settings_fields');

function eadv_site_id_callback()
{
    $value = get_option('eadv_site_id');
    echo '<input type="text" name="eadv_site_id" value="' . esc_attr($value) . '" />';
}

function eadv_magic_code_id_callback()
{
    $value = get_option('eadv_magic_code_id');
    echo '<input type="text" name="eadv_magic_code_id" value="' . esc_attr($value) . '" />';
}

?>